@@ -9,7 +9,7 @@ def send_message(webhook_url=None,
         raise ValueError('A text is needed.')
 
     response = requests.post(
-        self.webhook_url, data=json.dumps(self.slack_data),
+        webhook_url, data=json.dumps(slack_data),
         headers={'Content-Type': 'application/json'}
         )
     if response.status_code != 200:
